Chain

Struct Chain 

#[non_exhaustive]
pub struct Chain<T, U> {
#[doc(hidden)]
pub first: T,
#[doc(hidden)]
pub second: U,
#[doc(hidden)]
pub done_first: bool, }
🔬This is a nightly-only experimental API. (core_io #154046)
Adapter to chain together two readers.

This struct is generally created by calling chain on a reader. Please see the documentation of chain for more details.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.

#[doc(hidden)]
first: T
🔬This is a nightly-only experimental API. (core_io_internals)

#[doc(hidden)]
second: U
🔬This is a nightly-only experimental API. (core_io_internals)

#[doc(hidden)]
done_first: bool
🔬This is a nightly-only experimental API. (core_io_internals)

Implementations

Source

impl<T, U> Chain<T, U>

1.20.0 · Source

pub fn into_inner(self) -> (T, U)

Consumes the Chain, returning the wrapped readers.

Examples
use std::io;
use std::io::prelude::*;
use std::fs::File;

fn main() -> io::Result<()> {
    let mut foo_file = File::open("foo.txt")?;
    let mut bar_file = File::open("bar.txt")?;

    let chain = foo_file.chain(bar_file);
    let (foo_file, bar_file) = chain.into_inner();
    Ok(())
}
1.20.0 · Source

pub fn get_ref(&self) -> (&T, &U)

Gets references to the underlying readers in this Chain.

Care should be taken to avoid modifying the internal I/O state of the underlying readers as doing so may corrupt the internal state of this Chain.

Examples
use std::io;
use std::io::prelude::*;
use std::fs::File;

fn main() -> io::Result<()> {
    let mut foo_file = File::open("foo.txt")?;
    let mut bar_file = File::open("bar.txt")?;

    let chain = foo_file.chain(bar_file);
    let (foo_file, bar_file) = chain.get_ref();
    Ok(())
}
1.20.0 · Source

pub fn get_mut(&mut self) -> (&mut T, &mut U)

Gets mutable references to the underlying readers in this Chain.

Care should be taken to avoid modifying the internal I/O state of the underlying readers as doing so may corrupt the internal state of this Chain.

Examples
use std::io;
use std::io::prelude::*;
use std::fs::File;

fn main() -> io::Result<()> {
    let mut foo_file = File::open("foo.txt")?;
    let mut bar_file = File::open("bar.txt")?;

    let mut chain = foo_file.chain(bar_file);
    let (foo_file, bar_file) = chain.get_mut();
    Ok(())
}