Take

Struct Take 

#[non_exhaustive]
pub struct Take<T> {
#[doc(hidden)]
pub inner: T,
#[doc(hidden)]
pub len: u64,
#[doc(hidden)]
pub limit: u64, }
🔬This is a nightly-only experimental API. (core_io #154046)
Reader adapter which limits the bytes read from an underlying reader.

This struct is generally created by calling take on a reader. Please see the documentation of take for more details.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.

#[doc(hidden)]
inner: T
🔬This is a nightly-only experimental API. (core_io_internals)

#[doc(hidden)]
len: u64
🔬This is a nightly-only experimental API. (core_io_internals)

#[doc(hidden)]
limit: u64
🔬This is a nightly-only experimental API. (core_io_internals)

Implementations

Source

impl<T> Take<T>

1.0.0 · Source

pub fn limit(&self) -> u64

Returns the number of bytes that can be read before this instance will return EOF.

Note

This instance may reach EOF after reading fewer bytes than indicated by this method if the underlying Read instance reaches EOF.

Examples
use std::io;
use std::io::prelude::*;
use std::fs::File;

fn main() -> io::Result<()> {
    let f = File::open("foo.txt")?;

    // read at most five bytes
    let handle = f.take(5);

    println!("limit: {}", handle.limit());
    Ok(())
}
pub fn position(&self) -> u64

🔬This is a nightly-only experimental API. (seek_io_take_position #97227)

Returns the number of bytes read so far.

1.27.0 · Source

pub fn set_limit(&mut self, limit: u64)

Sets the number of bytes that can be read before this instance will return EOF. This is the same as constructing a new Take instance, so the amount of bytes read and the previous limit value don’t matter when calling this method.

Examples
use std::io;
use std::io::prelude::*;
use std::fs::File;

fn main() -> io::Result<()> {
    let f = File::open("foo.txt")?;

    // read at most five bytes
    let mut handle = f.take(5);
    handle.set_limit(10);

    assert_eq!(handle.limit(), 10);
    Ok(())
}
1.15.0 · Source

pub fn into_inner(self) -> T

Consumes the Take, returning the wrapped reader.

Examples
use std::io;
use std::io::prelude::*;
use std::fs::File;

fn main() -> io::Result<()> {
    let mut file = File::open("foo.txt")?;

    let mut buffer = [0; 5];
    let mut handle = file.take(5);
    handle.read(&mut buffer)?;

    let file = handle.into_inner();
    Ok(())
}
1.20.0 · Source

pub fn get_ref(&self) -> &T

Gets a reference to the underlying reader.

Care should be taken to avoid modifying the internal I/O state of the underlying reader as doing so may corrupt the internal limit of this Take.

Examples
use std::io;
use std::io::prelude::*;
use std::fs::File;

fn main() -> io::Result<()> {
    let mut file = File::open("foo.txt")?;

    let mut buffer = [0; 5];
    let mut handle = file.take(5);
    handle.read(&mut buffer)?;

    let file = handle.get_ref();
    Ok(())
}
1.20.0 · Source

pub fn get_mut(&mut self) -> &mut T

Gets a mutable reference to the underlying reader.

Care should be taken to avoid modifying the internal I/O state of the underlying reader as doing so may corrupt the internal limit of this Take.

Examples
use std::io;
use std::io::prelude::*;
use std::fs::File;

fn main() -> io::Result<()> {
    let mut file = File::open("foo.txt")?;

    let mut buffer = [0; 5];
    let mut handle = file.take(5);
    handle.read(&mut buffer)?;

    let file = handle.get_mut();
    Ok(())
}