#[non_exhaustive]pub struct Chain<T, U> {
#[doc(hidden)] pub first: T,
#[doc(hidden)] pub second: U,
#[doc(hidden)] pub done_first: bool,
}🔬This is a nightly-only experimental API. (
core_io #154046)Expand description
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.#[doc(hidden)]first: T🔬This is a nightly-only experimental API. (
core_io_internals)#[doc(hidden)]second: U🔬This is a nightly-only experimental API. (
core_io_internals)#[doc(hidden)]done_first: bool🔬This is a nightly-only experimental API. (
core_io_internals)Implementations
Sourceimpl<T, U> Chain<T, U>
impl<T, U> Chain<T, U>
1.20.0 · Sourcepub fn into_inner(self) -> (T, U)
pub fn into_inner(self) -> (T, U)
Consumes the Chain, returning the wrapped readers.
Examples
1.20.0 · Sourcepub fn get_ref(&self) -> (&T, &U)
pub fn get_ref(&self) -> (&T, &U)
Gets references to the underlying readers in this Chain.
Care should be taken to avoid modifying the internal I/O state of the
underlying readers as doing so may corrupt the internal state of this
Chain.
Examples