#[non_exhaustive]pub struct Take<T> {
#[doc(hidden)] pub inner: T,
#[doc(hidden)] pub len: u64,
#[doc(hidden)] pub limit: u64,
}🔬This is a nightly-only experimental API. (
core_io #154046)Expand description
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.#[doc(hidden)]inner: T🔬This is a nightly-only experimental API. (
core_io_internals)#[doc(hidden)]len: u64🔬This is a nightly-only experimental API. (
core_io_internals)#[doc(hidden)]limit: u64🔬This is a nightly-only experimental API. (
core_io_internals)Implementations
Sourceimpl<T> Take<T>
impl<T> Take<T>
1.0.0 · Sourcepub fn limit(&self) -> u64
pub fn limit(&self) -> u64
Sourcepub fn position(&self) -> u64
🔬This is a nightly-only experimental API. (seek_io_take_position #97227)
pub fn position(&self) -> u64
seek_io_take_position #97227)Returns the number of bytes read so far.
1.27.0 · Sourcepub fn set_limit(&mut self, limit: u64)
pub fn set_limit(&mut self, limit: u64)
Sets the number of bytes that can be read before this instance will
return EOF. This is the same as constructing a new Take instance, so
the amount of bytes read and the previous limit value don’t matter when
calling this method.
Examples
1.15.0 · Sourcepub fn into_inner(self) -> T
pub fn into_inner(self) -> T
Consumes the Take, returning the wrapped reader.
Examples
1.20.0 · Sourcepub fn get_ref(&self) -> &T
pub fn get_ref(&self) -> &T
Gets a reference to the underlying reader.
Care should be taken to avoid modifying the internal I/O state of the
underlying reader as doing so may corrupt the internal limit of this
Take.
Examples